==> gromacs_4.0.7.orig.tar.gz: gromacs-4.0.7/src/kernel/h_db.h <==
/*
 * $Id$
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */

#ifndef _h_db_h
#define _h_db_h

#include "sysstuff.h"
#include "hackblock.h"

/* number of control atoms for each 'add' type */
extern const int ncontrol[];
  
/* functions for the h-database */

extern void read_ab(char *line,char *fn,t_hack *ab);
/* Read one add block */

extern int read_h_db(char *fn,t_hackblock **ah);
/* Read the database from file */

extern void print_ab(FILE *out,t_hack *ab,char *nname);
/* print one add block */

extern void print_h_db(FILE *out,int nh,t_hackblock ah[]);
/* Print the database to file */

extern int compaddh(const void *a,const void *b);

extern t_hackblock *search_h_db(int nh,t_hackblock ah[],char *key);
/* Search for an entry in the database */



#endif	/* _h_db_h */

==> gromacs_4.5.5.orig.tar.gz: gromacs-4.5.5/src/kernel/h_db.h <==
/*
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */

#ifndef _h_db_h
#define _h_db_h

#include "sysstuff.h"
#include "hackblock.h"

/* number of control atoms for each 'add' type */
extern const int ncontrol[];
  
/* functions for the h-database */

extern void read_ab(char *line,const char *fn,t_hack *ab);
/* Read one add block */

extern int read_h_db(const char *ffdir,t_hackblock **ah);
/* Read the database from hdb file(s) in ffdir or current dir */

extern void print_ab(FILE *out,t_hack *ab,char *nname);
/* print one add block */

extern void print_h_db(FILE *out,int nh,t_hackblock ah[]);
/* Print the database to file */

extern int compaddh(const void *a,const void *b);

extern t_hackblock *search_h_db(int nh,t_hackblock ah[],char *key);
/* Search for an entry in the database */



#endif	/* _h_db_h */
